///
// Replication file for Table 3 in "Why Wait for a Replication Crisis? Energy Efficiency Evaluations Need Pre-Analysis Plans"
///

// First, I undertake a random selection of individual characteristics from the experimental dataset 
* Step 1: list all the variables in the dataset in an Excel spreadsheet C:\Behave 2016\Energy Efficiency special issue\Random selection of covariates for heterogeneity analysis.xls
* Step 2: take the first 20 (of the randomly sorted list) for doing treatment heterogeneity analysis

// Second, I open the Stata dataset to perform the analysis to create Table 3
use "C:\Behave 2016\Energy Efficiency special issue\Replication dataset for Why wait for a replication crisis.dta", clear

* Step 1: create the interaction terms for the randomly selected variables
recode switch2014 1=0 0=1, gen (switch2014new)
gen t1t3_otherpay=t1t3*otherpay
gen t1t3_higher=t1t3*higher
gen t1t3_yessolely=t1t3*yessolely
gen t1t3_socialgrade=t1t3*socialgrade
gen t1t3_post16=t1t3*post16
gen t1t3_electricv=t1t3*electricv
gen t1t3_student=t1t3*student
gen t1t3_female=t1t3*female
gen t1t3_weekevenings=t1t3*weekevenings
gen t1t3_children=t1t3*children
gen t1t3_educnoresponse=t1t3*educnoresponse
gen t1t3_dryertimer=t1t3*dryertimer
gen t1t3_occupants=t1t3*occupants
gen t1t3_lifestyleright=t1t3*lifestyleright
gen t1t3_switch2014new=t1t3*switch2014new
gen t1t3_prepayment=t1t3*prepayment
gen t1t3_toudk=t1t3*toudk
gen t1t3_scotland=t1t3*scotland
gen t1t3_qualif16=t1t3*qualif16
gen t1t3_touno=t1t3*touno

// Step 2: run the regression analysis to obtain the coefficients and t-statistics for column 2-3 of Table 3
** the prefix -svy- in Stata is the command which tells Stata that the data is survey data to ensure that the survey weights are used in the analysis
** accounting for survey design is necessary to ensure standard errors, confidence intervals, and test statistics are computed correctly
** NB the coefficients reported in the Table are rounded to two decimal places

* svyset the data (so that weighted analysis can be used)
svyset [pweight=weight]

* Row 1: All energy payers
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher 

* Row 2: Owns an electric vehicle
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_electricv

* Row 3: Educated up until university level interaction
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_higher

* Row 4: Educated up until 18 interaction
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno post16 t1t3_post16

* Row 5: Educated up until 16 interaction
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno qualif16 t1t3_qualif16

* Row 6: Educational status not reported
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno educnoresponse t1t3_educnoresponse

* Row 7: Solely responsible for paying bills
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_yessolely

* Row 8: Social grade
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_socialgrade

* Row 9: Owns tumble dryer with timer
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_dryertimer

* Row 10: Number of household occupants
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_occupants

* Row 11: Number of children over 15 in household
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_children

* Row 12: Home is usually occupied on weeknights
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_weekevenings

* Row 13: Home is mostly empty on weeknights but with people home during the day and weekend
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female children dryertimer occupants switch2014new prepayment scotland touno lifestyleright higher t1t3_lifestyleright

* Row 14: Switched tariff this year
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_switch2014

* Row 16: Pre-pays for electricity
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_prepayment

* Row 17: Pays for electricity by another method 
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new otherpay scotland touno higher t1t3_otherpay

* Row 18: Is not currently on a time of use tariff
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_touno

* Row 19: Doesn't know if they are on a time of use tariff
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland toudk higher t1t3_toudk

* Row 20: Lives in Scotland
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_scotland

* Row 21: Female
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_female

* Row 22: Student
svy: regress switch t1t3 otherpay yessolely socialgrade electricv student female weekevenings children dryertimer occupants switch2014new prepayment scotland touno higher t1t3_student


// Step 3: obtaining the sample size per sub-group for column 4 in Table 3
sum panelid
tab electricv
tab higher
tab post16
tab qualif16
tab educnoresponse
tab yessolely
tab socialgrade
tab dryertimer
tab occupants
tab children
tab weekevenings
tab lifestyleright
tab switch2014new
tab prepayment
tab otherpay
tab touno
tab toudk
tab scotland
tab female
tab student




